import gym
from gym import error, spaces, utils
from gym.utils import seeding

class Basic(gym.Env):
    metadata = {'render.modes': ['human']}

    def __init__(self):
        print('init basic')
        
    def step(self, action):
        print('step')
    
    def reset(self):
        print('reset')
    
    def render(self, mode='human'):
        print('render')
    
    def close(self):
        print('close')
    


from setuptools import setup, find_packages

setup(name='gym-push',
      packages=find_packages(),
      package_data={
        '': ['*.csv', '*.npy'],
      },      
      version='0.0.9',
      install_requires=['gym', 'numpy', 'pandas', 'joblib'],  # And any other dependencies foo needs,
      author='Kieran Fraser',
      author_email='kfraser@tcd.ie',
) 